% function [ output_args ] = demo3DDiffeoSynth( input_args )
%This demo illustrates different ways to sample from points in a
%diffeomorphic model.

scriptname = mfilename;

scriptpath = which(scriptname);
tokens = regexp(scriptpath, filesep);

cd(scriptpath(1:tokens(end)));

param.targetDirectory = scriptname;



load('helamodel.mat')

cellinds = find(all(~isnan(model.cellShapeModel.positions),2));

positions = model.cellShapeModel.positions(cellinds,:);

c = 1;

gmmfitfile = ['gmmfit.mat'];  
if ~exist(gmmfitfile, 'file')
    objgmm = {};
    while c < 20
        tryagain = 0;
        while tryagain < 2
            try
                objgmm{c} = gmdistribution.fit(positions,c, 'replicates', 200);
                break
            catch
                tryagain = tryagain + 1;    
            end
        end
        c = c+1;
    end
    save(gmmfitfile, 'objgmm')
else
    load(gmmfitfile)
end

[~, aicind] = min(cellfun(@(x) x.AIC, objgmm));
[~, bicind] = min(cellfun(@(x) x.BIC, objgmm));

gmm_aic = objgmm{aicind};
gmm_bic = objgmm{bicind};



numimgs = 5;
for i = 1:numimgs
    %sample from the gmm ANDed to the convex hull of the triangulation
    simplex_idx = nan;
    while isnan(simplex_idx)
        point = gmm_aic.random;
        simplex_idx = tsearchn(model.cellShapeModel.positions,model.cellShapeModel.tessellation,point);
    end
    points(i,:) = point;
    
    param.position = point;
    
    
    savedir = [scriptpath '_img' num2str(i)];
    if ~exist(savedir, 'dir')
        mkdir(savedir)
    end
    cd(savedir);
    
    param.targetDirectory = [scriptname filesep 'img' num2str(i)];
    
    imgs{i} = model2img({model}, param);
end


